Package: henna
Type: Package
Title: A Versatile Visualization Suite
Version: 0.8.5
Authors@R: person('Andrei-Florian', 'Stoica', 
      email='andreistoica@foxmail.com',
     role=c('aut','cre'),
     comment=c(ORCID='0000-0002-5253-0826'))
Description: A visualization suite primarily designed for single-cell
    RNA-sequencing data analysis applications but well-suited for
    other purposes as well. It introduces novel plots to represent two-variable
    and frequency data and optimizes some commonly used plotting options
    (e.g., correlation, network, density, alluvial and volcano plots) 
    for ease of usage and flexibility.
License: MIT + file LICENSE
Imports: abdiv, dplyr, ggalluvial, ggeasy, ggforce, ggraph, ggnewscale,
        ggplot2, ggrepel, grDevices, liver, methods, paletteer,
        reshape2, rlang, stats, tidygraph, viridis, withr
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: EnhancedVolcano, qs2, testthat (>= 3.0.0)
URL: https://github.com/andrei-stoica26/henna
BugReports: https://github.com/andrei-stoica26/henna/issues
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-13 02:39:38 UTC; Andrei
Author: Andrei-Florian Stoica [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5253-0826>)
Maintainer: Andrei-Florian Stoica <andreistoica@foxmail.com>
Repository: CRAN
Date/Publication: 2026-07-13 05:40:02 UTC
