# Generated by roxygen2: do not edit by hand

export(centerTitle)
export(classPlot)
export(connectedComponents)
export(convexHull)
export(correlationPlot)
export(densityPlot)
export(dpColors)
export(hpColors)
export(hullPlot)
export(isPointOnBoundary)
export(isPointOnSeg)
export(labelPoints)
export(networkPlot)
export(pointsToSegments)
export(radialPlot)
export(rankPlot)
export(rankSummary)
export(reorderDF)
export(riverPlot)
export(rpColors)
export(tilePlot)
export(vertexComponents)
export(volcanoPlot)
importFrom(abdiv,euclidean)
importFrom(dplyr,count)
importFrom(dplyr,mutate)
importFrom(ggalluvial,StatStratum)
importFrom(ggalluvial,geom_alluvium)
importFrom(ggalluvial,geom_stratum)
importFrom(ggeasy,easy_remove_axes)
importFrom(ggforce,geom_circle)
importFrom(ggnewscale,new_scale_color)
importFrom(ggnewscale,new_scale_fill)
importFrom(ggplot2,aes)
importFrom(ggplot2,after_stat)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,expand_limits)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_label)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_polygon)
importFrom(ggplot2,geom_segment)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_tile)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggproto)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,margin)
importFrom(ggplot2,scale_color_discrete)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_gradientn)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_fill_viridis_d)
importFrom(ggplot2,stat_density_2d)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,theme_linedraw)
importFrom(ggplot2,theme_minimal)
importFrom(ggplot2,theme_void)
importFrom(ggplot2,xlab)
importFrom(ggraph,geom_edge_link)
importFrom(ggraph,geom_node_point)
importFrom(ggraph,geom_node_text)
importFrom(ggraph,ggraph)
importFrom(ggraph,scale_edge_width)
importFrom(ggrepel,geom_label_repel)
importFrom(ggrepel,geom_text_repel)
importFrom(grDevices,chull)
importFrom(grDevices,hcl.colors)
importFrom(liver,minmax)
importFrom(methods,is)
importFrom(paletteer,paletteer_c)
importFrom(reshape2,melt)
importFrom(rlang,.data)
importFrom(stats,density)
importFrom(stats,runif)
importFrom(stats,setNames)
importFrom(tidygraph,activate)
importFrom(tidygraph,as_tbl_graph)
importFrom(viridis,scale_color_viridis)
importFrom(viridis,scale_fill_viridis)
importFrom(withr,with_seed)
