% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hull_plot.R
\name{borderCoords}
\alias{borderCoords}
\title{Find the coordinates where a vertical or horizontal line intersects the hull}
\usage{
borderCoords(df, axis, axisIntersect)
}
\arguments{
\item{df}{A four-column data frame representing segments.}

\item{axis}{An integer representing the axis intersected by the vertical or
horizontal line, x (1) or y (2).}

\item{axisIntersect}{The coordinate where the vertical or horizontal line
intersects the relevant axis.}
}
\value{
A vector of size two representing the coordinates of the two
intersection points between the vertical or horizontal line and the convex
hull on the axis different from the input axis.
}
\description{
This function finds the coordinates where a vertical or horizontal line
intersects the hull.
}
\keyword{internal}
